;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "switch-window" "20250401.839"
  "A *visual* way to switch window."
  '((emacs "24"))
  :url "https://github.com/dimitri/switch-window"
  :commit "8f771b571a1e60fac2d2a9845c0a5a52d5b440df"
  :revdesc "8f771b571a1e"
  :keywords '("convenience")
  :authors '(("Dimitri Fontaine" . "dim@tapoueh.org")
             ("Feng Shu" . "tumashu@163.com"))
  :maintainers '(("Dimitri Fontaine" . "dim@tapoueh.org")
                 ("Feng Shu" . "tumashu@163.com")))
